;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "dwim-shell-command" "20251013.1518"
  "Shell commands with DWIM behaviour."
  '((emacs "28.1"))
  :url "https://github.com/xenodium/dwim-shell-command"
  :commit "5ffad4ac5702e046166d0f59a3d3d790aa8274a2"
  :revdesc "5ffad4ac5702")
